=================
``desmod.config``
=================

.. automodule:: desmod.config

.. autoclass:: ConfigError
   :members:

.. autoclass:: NamedConfig
   :inherited-members:
   :members:

.. autoclass:: NamedManager
   :members:

.. autofunction:: apply_user_overrides

.. autofunction:: parse_user_factors

.. autofunction:: parse_user_factor

.. autofunction:: factorial_config

.. autofunction:: fuzzy_match

.. autofunction:: fuzzy_lookup
